@@ -2,7 +2,7 @@ package Module::Install::XSUtil;
 
 use 5.005_03;
 
-$VERSION = '0.06';
+$VERSION = '0.07';
 
 use Module::Install::Base;
 @ISA     = qw(Module::Install::Base);
@@ -42,11 +42,12 @@ sub _xs_initialize{
 	return;
 }
 
+# GNU C Compiler
 sub _is_gcc{
-	return defined $Config{gccversion};
+	return $Config{gccversion};
 }
 
-# Microsoft Visual C++ Compiler
+# Microsoft Visual C++ Compiler (cl.exe)
 sub _is_msvc{
 	return $Config{cc} =~ /\A cl \b /xmsi;
 }
@@ -111,7 +112,7 @@ sub cc_append_to_inc{
 	}
 
 	my $mm    = $self->makemaker_args;
-	my $paths = join q{ }, map{ qq{"-I$_"} } @dirs;
+	my $paths = join q{ }, map{ s{\\}{\\\\}g; qq{"-I$_"} } @dirs;
 
 	if($mm->{INC}){
 		$mm->{INC} .=  q{ } . $paths;
@@ -186,8 +187,8 @@ sub requires_xs{
 
 	while(my $module = each %added){
 		my $mod_basedir = File::Spec->join(split /::/, $module);
-		my $rx_header = qr{\A (.+ $mod_basedir) .+ \.h \z}xmsi;
-		my $rx_lib    = qr{\A (.+ $mod_basedir) .+ (\w+) \. (?: lib | dll | a) \z}xmsi;
+		my $rx_header = qr{\A ( .+ \Q$mod_basedir\E ) .+ \.h(?:pp)? \z}xmsi;
+		my $rx_lib    = qr{\A ( .+ \Q$mod_basedir\E ) .+ (\w+) \. (?: lib | dll | a) \z}xmsi;
 
 		SCAN_INC: foreach my $inc_dir(@INC){
 			my @dirs = grep{ -e } File::Spec->join($inc_dir, 'auto', $mod_basedir), File::Spec->join($inc_dir, $mod_basedir);
@@ -269,7 +270,7 @@ sub cc_include_paths{
     foreach my $dir(@dirs){
 		my $prefix = quotemeta( File::Spec->catfile($dir, '') );
 		find(sub{
-			return unless / \.h \z/xms;
+			return unless / \.h(?:pp)? \z/xms;
 
 			(my $h_file = $File::Find::name) =~ s/ \A $prefix //xms;
 			$h_map->{$h_file} = $File::Find::name;
@@ -390,7 +391,7 @@ sub cc_append_to_funclist{
 	my $mm = $self->makemaker_args;
 
 	push @{$mm->{FUNCLIST} ||= []}, @functions;
-	$mm->{DL_FUNCS} ||= { '$(NAME)' => ['boot_$(NAME)'] };
+	$mm->{DL_FUNCS} ||= { '$(NAME)' => [] };
 
 	return;
 }
@@ -441,7 +442,7 @@ Module::Install::XSUtil - Utility functions for XS modules
 
 =head1 VERSION
 
-This document describes Module::Install::XSUtil version 0.06.
+This document describes Module::Install::XSUtil version 0.07.
 
 =head1 SYNOPSIS
 
@@ -556,6 +557,8 @@ L<Module::Install::CheckLib>.
 
 L<Devel::CheckLib>.
 
+L<ExtUtils::MakeMaker>.
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright (c) 2009, Goro Fuji (gfx). Some rights reserved.
